/*
 * iconset.h - generic handling of iconsets
 * Copyright (C) 2003  Totemworks, LLC
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef CS_ICONSET_H
#define CS_ICONSET_H

#include<qstring.h>
#include<qstringlist.h>
#include<qvaluevector.h>

class QImage;
class QPixmap;
class QMimeSourceFactory;

class Impix
{
public:
	Impix();
	Impix(const QPixmap &);
	Impix(const QImage &);
	Impix(const Impix &);
	Impix & operator=(const Impix &from);
	~Impix();

	void unload();
	bool isNull() const;

	const QPixmap & pixmap() const;
	const QImage & image() const;
	void setPixmap(const QPixmap &);
	void setImage(const QImage &);

	operator const QPixmap &() const { return pixmap(); }
	operator const QImage &() const { return image(); }
	Impix & operator=(const QPixmap &from) { setPixmap(from); return *this; }
	Impix & operator=(const QImage &from) { setImage(from); return *this; }

private:
	class Private;
	Private *d;
};

class SimpleAnim : public QValueVector<Impix>
{
public:
	SimpleAnim();
	~SimpleAnim();

	int speed() const;
	void setSpeed(int);

private:
	int v_speed;
};

class Icon
{
public:
	Icon(const Impix &icon=Impix());
	Icon(const Impix &, const SimpleAnim &);
	~Icon();

	const Impix & icon() const;
	const SimpleAnim & animation() const;
	bool isAnimated() const;

	void setIcon(const Impix &);
	void setAnimation(const SimpleAnim &);
	void clearAnimation();

	operator const QPixmap &() const { return icon().pixmap(); }
	operator const QImage &() const { return icon().image(); }

private:
	Impix v_icon;
	SimpleAnim *v_anim;
};

class Iconset
{
public:
	Iconset();
	Iconset(Iconset &);
	Iconset & operator=(Iconset &);
	~Iconset();

	const Icon & icon(const QString &) const;
	void setIcon(const QString &, const Icon &);
	void removeIcon(const QString &);
	void clear();

	QMimeSourceFactory *createMimeSourceFactory() const;

private:
	class Private;
	Private *d;
};

#endif
